AsyncEscPosPrinter class

Inheritance

Constructors

AsyncEscPosPrinter(DeviceConnection printerConnection, int printerDpi, double printerWidthMM, int printerNbrCharactersPerLine)

Properties

getPrinterCharSizeWidthPx int
no setterinherited
getPrinterDpi int
no setterinherited
getPrinterNbrCharactersPerLine int
no setterinherited
getPrinterWidthMM double
no setterinherited
getPrinterWidthPx int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
printerCharSizeWidthPx int
getter/setter pairinherited
printerConnection DeviceConnection
final
printerDpi int
finalinherited
printerNbrCharactersPerLine int?
getter/setter pairinherited
printerWidthMM double
finalinherited
printerWidthPx int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textsToPrint List<String?>
getter/setter pair

Methods

addTextToPrint(String? textToPrint) AsyncEscPosPrinter
clearTextsToPrint() → void
imageToBytes(Image image, bool gradient, int size) List<int>
inherited
mmToPx(double mmSize) int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parsedToBytes({int feedCount = 0, bool useCut = false, bool openDrawer = false}) Future<Uint8List>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited