BatchPrintOptions class

Constructors

BatchPrintOptions(int iterations, {Duration delay = Duration.zero, int feedCount = 0, bool useCut = false})
const
BatchPrintOptions.perNContent(int n, {Duration delay = Duration.zero, int feedCount = 0, bool useCut = false})
const

Properties

delay Duration
Delay between each print
final
feedCount int
Feed count for each print
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useCut bool
Whether each print should be appended cut command at the end of content
final

Methods

getStartEnd(int contentLength) Iterable<List<Object>>
Returns an iteration generator that generates 3 values (in order):
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

full → const BatchPrintOptions