EasyThermalPrinter class

Properties

connectedDevices List<FluetoothDevice>
no setter
hashCode int
The hash code for this object.
no setterinherited
paperSize PaperSize
no setter
printerNbrCharactersPerLine int
no setter
printerWidth double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

base64toHexadecimal(String data, int size) String
connect(FluetoothDevice device, {Duration timeout = const Duration(seconds: 5)}) Future<ConnectionStatus>
convertToHtml(String formattedText) String
disconnect(String uuid) Future<ConnectionStatus>
getConnectedDevices() Future<List<FluetoothDevice>>
mmToPx(int mm) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printQR(String data, String uuid, {int size = 120, int feedCount = 0, bool useCut = false, bool openDrawer = false}) Future<void>
printReceiptImage(List<int> bytes, String uuid, {int width = 120, int feedCount = 0, bool useCut = false, bool openDrawer = false}) Future<void>
printReceiptText(ReceiptSectionText receiptSectionText, String uuid, {int feedCount = 0, bool useCut = false, bool useRaster = false, bool openDrawer = false, double duration = 0, double? textScaleFactor, BatchPrintOptions? batchPrintOptions}) Future<void>
pxToMM(int pixel) int
scan() Future<List<FluetoothDevice>>
setPaperSize(PaperSize paperSize) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EasyThermalPrinter
no setter

Constants

printerDpi → const int