EscPosPrinter class

Inheritance

Constructors

EscPosPrinter(DeviceConnection printerConnection, EscPosCharsetEncoding? charsetEncoding, EscPosPrinterCommands? printer, int printerDpi, double printerWidthMM, int printerNbrCharactersPerLine)

Properties

charsetEncoding EscPosCharsetEncoding?
final
getEncoding EscPosCharsetEncoding?
no setter
getPrinterCharSizeWidthPx int
no setterinherited
getPrinterDpi int
no setterinherited
getPrinterNbrCharactersPerLine int
no setterinherited
getPrinterWidthMM double
no setterinherited
getPrinterWidthPx int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
printer EscPosPrinterCommands?
final
printerCharSizeWidthPx int
getter/setter pairinherited
printerConnection DeviceConnection
final
printerDpi int
finalinherited
printerNbrCharactersPerLine int?
getter/setter pairinherited
printerWidthMM double
finalinherited
printerWidthPx int
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

imageToBytes(Image image, bool gradient, int size) List<int>
inherited
mmToPx(double mmSize) int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printFormattedText(String text, int dotsFeedPaper) Future<EscPosPrinter?>
printFormattedTextAndCut(String text, {double? mmFeedPaper, int? dotsFeedPaper, required bool useCut, required bool openDrawer}) EscPosPrinter?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited