EscPosPrinterCommands class

Constructors

EscPosPrinterCommands(DeviceConnection _printerConnection, EscPosCharsetEncoding? charsetEncoding)
Create constructor of EscPosPrinterCommands @param _printerConnection an instance of a class which implement DeviceConnection

Properties

getCharsetEncoding EscPosCharsetEncoding
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cutPaper() → void
feedPaper(int dots) → void
newLine() EscPosPrinterCommands?
newLineAlign(List<int>? align) EscPosPrinterCommands?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openCashBox() → void
printAllCharsetsEncodingCharacters() → void
printBarcode(Barcode? barcode) EscPosPrinterCommands
printCharsetEncodingCharacters(int charsetId) → void
printCharsetsEncodingCharactersWithId(List<int> charsetsId) → void
printImage(Uint8List image) EscPosPrinterCommands
printQRCode(int qrCodeType, String text, int size) EscPosPrinterCommands
printText(String text, List<int>? textSize, List<int>? textColor, List<int>? textReverseColor, List<int>? textBold, List<int>? textUnderline, List<int>? textDoubleStrike) EscPosPrinterCommands
reset() → void
setAlign(Uint8List align) EscPosPrinterCommands
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convertQRCodeToBytes(String data, int size) Uint8List
imageToBytes(Image imageSrc) List<int>