EscPosPrinterSize class

Implementers

Constructors

EscPosPrinterSize(int printerDpi, double printerWidthMM, int _printerNbrCharactersPerLine)

Properties

getPrinterCharSizeWidthPx int
no setter
getPrinterDpi int
no setter
getPrinterNbrCharactersPerLine int
no setter
getPrinterWidthMM double
no setter
getPrinterWidthPx int
no setter
hashCode int
The hash code for this object.
no setterinherited
printerCharSizeWidthPx int
getter/setter pair
printerDpi int
final
printerNbrCharactersPerLine int?
getter/setter pair
printerWidthMM double
final
printerWidthPx int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

imageToBytes(Image image, bool gradient, int size) List<int>
mmToPx(double mmSize) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

inchToMM → const double