PrinterTextParser class
Constructors
- PrinterTextParser(EscPosPrinter _printer)
Properties
-
getLastTextBold
→ List<
int> -
no setter
-
getLastTextColor
→ List<
int> -
no setter
-
getLastTextDoubleStrike
→ List<
int> -
no setter
-
getLastTextReverseColor
→ List<
int> -
no setter
-
getLastTextSize
→ List<
int> -
no setter
-
getLastTextUnderline
→ List<
int> -
no setter
- getPrinter → EscPosPrinter
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
textBold
↔ List<
List< int> > -
getter/setter pair
-
textColor
↔ List<
List< int> > -
getter/setter pair
-
textDoubleStrike
↔ List<
List< int> > -
getter/setter pair
-
textReverseColor
↔ List<
List< int> > -
getter/setter pair
-
textSize
↔ List<
List< int> > -
getter/setter pair
-
textUnderline
↔ List<
List< int> > -
getter/setter pair
Methods
-
addTextBold(
List< int> newTextBold) → void -
addTextColor(
List< int> newTextColor) → void -
addTextDoubleStrike(
List< int> newTextDoubleStrike) → void -
addTextReverseColor(
List< int> newTextReverseColor) → void -
addTextSize(
List< int> newTextSize) → void -
addTextUnderline(
List< int> newTextUnderline) → void -
dropLastTextBold(
) → void -
dropLastTextColor(
) → void -
dropLastTextDoubleStrike(
) → void -
dropLastTextReverseColor(
) → void -
dropLastTextSize(
) → void -
dropLastTextUnderline(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
) → List< PrinterTextParserLine?> -
setFormattedText(
String text) → PrinterTextParser -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- attrBarcodeHeight → const String
- attrBarcodeTextPosition → const String
- attrBarcodeTextPositionAbove → const String
- attrBarcodeTextPositionBelow → const String
- attrBarcodeTextPositionNone → const String
- attrBarcodeType → const String
- attrBarcodeType128 → const String
- attrBarcodeTypeEAN8 → const String
- attrBarcodeTypeEAN13 → const String
- attrBarcodeTypeUPCA → const String
- attrBarcodeTypeUPCE → const String
- attrBarcodeWidth → const String
- attrFormatTextFontColor → const String
- attrFormatTextFontColorBgBlack → const String
- attrFormatTextFontColorBgRed → const String
- attrFormatTextFontColorBlack → const String
- attrFormatTextFontColorRed → const String
- attrFormatTextFontSize → const String
- attrFormatTextFontSizeBig → const String
- attrFormatTextFontSizeBig2 → const String
- attrFormatTextFontSizeBig3 → const String
- attrFormatTextFontSizeBig4 → const String
- attrFormatTextFontSizeBig5 → const String
- attrFormatTextFontSizeBig6 → const String
- attrFormatTextFontSizeNormal → const String
- attrFormatTextFontSizeTall → const String
- attrFormatTextFontSizeWide → const String
- attrFormatTextUnderlineType → const String
- attrFormatTextUnderlineTypeDouble → const String
- attrFormatTextUnderlineTypeNormal → const String
- attrImageWidth → const String
- attrQRCodeSize → const String