PrinterTextParserBarcode class

Implemented types

Constructors

PrinterTextParserBarcode(PrinterTextParserColumn printerTextParserColumn, String textAlign, HashMap<String, String> barcodeAttributes, String code)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

length() int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print(EscPosPrinterCommands printerSocket) PrinterTextParserBarcode
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited