PrinterTextParserColumn class

Constructors

PrinterTextParserColumn(PrinterTextParserLine _textParserLine, String _textColumn)

Properties

getElements List<PrinterTextParserElement?>
no setter
getLine PrinterTextParserLine
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendBarcode(String textAlign, HashMap<String, String> barcodeAttributes, String code) → void
appendCut(String textAlign) → void
appendElement(PrinterTextParserElement element) → void
appendImage(String textAlign, HashMap<String, String> imageAttributes, String hexString) → void
appendQRCode(String textAlign, HashMap<String, String> qrCodeAttributes, String data) → void
appendString(String text, List<int> textSize, List<int> textColor, List<int> textReverseColor, List<int> textBold, List<int> textUnderline, List<int> textDoubleStrike) → void
appendStringText(String text) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prependElement(PrinterTextParserElement element) PrinterTextParserColumn
prependString(String text, List<int> textSize, List<int> textColor, List<int> textReverseColor, List<int> textBold, List<int> textUnderline, List<int> textDoubleStrike) PrinterTextParserColumn
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateSpace(int nbrSpace) String