PrinterTextParserImg class

Implemented types
Implementers

Constructors

PrinterTextParserImg(PrinterTextParserColumn printerTextParserColumn, String textAlign, HashMap<String, String> imageAttributes, {String? hexadecimalString, Uint8List? bytes})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair

Methods

length() int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print(EscPosPrinterCommands printerSocket) PrinterTextParserImg
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

base64ImageToHexadecimalString(EscPosPrinterSize printerSize, String base64Image, bool gradient, int size) String
bytesToHexadecimalString(List<int> bytes) String
hexadecimalStringToBytes(String hexString) Uint8List
imageToHexadecimalString(EscPosPrinterSize printerSize, Image image, bool gradient, int size) String