PrinterTextParserLine class

Constructors

PrinterTextParserLine(PrinterTextParser textParser, String textLine)

Properties

getColumns List<PrinterTextParserColumn?>
no setter
getNbrCharColumn int
no setter
getNbrCharColumnExceeded int
no setter
getNbrCharForgetted int
no setter
getNbrColumns int
no setter
getTextParser PrinterTextParser
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textLine String
final
textParser PrinterTextParser
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNbrCharColumnExceeded(int newValue) → void
setNbrCharForgotted(int newValue) PrinterTextParserLine
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited