PrinterTextParserQRCode class

Inheritance

Constructors

PrinterTextParserQRCode(PrinterTextParserColumn printerTextParserColumn, String textAlign, HashMap<String, String> qrCodeAttributes, String data)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pairinherited

Methods

length() int
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print(EscPosPrinterCommands printerSocket) PrinterTextParserImg
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initConstructor(PrinterTextParserColumn printerTextParserColumn, HashMap<String, String> qrCodeAttributes, String data) Uint8List