PrinterTextParserString class

Implemented types

Constructors

PrinterTextParserString(EscPosPrinter _printer, String _text, List<int> _textSize, List<int> _textColor, List<int> _textReverseColor, List<int> _textBold, List<int> _textUnderline, List<int> _textDoubleStrike)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

length() int
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
print(EscPosPrinterCommands printerSocket) PrinterTextParserString
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited