ReceiptSectionText class
Methods
addBarcode (String data , {int size = 20 })
→ void
addCut ()
→ void
addImage (String base64 , {int width = 120 , ReceiptAlignment alignment = ReceiptAlignment.center })
→ void
addLeftRightText (String leftText , String rightText , {String prefixText = '' , ReceiptTextStyleType leftStyle = ReceiptTextStyleType.normal , ReceiptTextStyleType rightStyle = ReceiptTextStyleType.normal , ReceiptTextSizeType leftSize = ReceiptTextSizeType.medium , ReceiptTextSizeType rightSize = ReceiptTextSizeType.medium , ReceiptTextStyleType prefixTextStyle = ReceiptTextStyleType.normal , int ? maxCharLeftText })
→ void
Handler tag of text (span or b) and put inside body html
This will generate left right text with two value input from parameter
leftText and rightText
addQR (String data , {int size = 20 })
→ void
addSpacer ({int count = 1 , bool useDashed = false })
→ void
Add new line as empty or dashed line.
count is how much line
if useDashed true line will print as dashed line
addSpacerPx ([int pixels = 1 ])
→ void
addText (String text , {ReceiptAlignment alignment = ReceiptAlignment.center , ReceiptTextStyleType style = ReceiptTextStyleType.normal , ReceiptTextSizeType size = ReceiptTextSizeType.medium })
→ void
Handler tag of text (p or b) and put inside body html
This will generate single line text left, center or right
text value of text will print
alignment to set alignment of text
style define normal or bold
size to set size of text small, medium, large or extra large
getContent ([int start = 0 , int ? end ])
→ String
Build a page from html, CollectionStyle.all is defined CSS inside html
_data will collect all generated tag from model ReceiptText,
ReceiptTextLeftRight and ReceiptLine
getSection ([int start = 0 , int ? end ])
→ ReceiptSectionText
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
easy_thermal_printer 1.0.1