EscPosPrinterCommands class
Constructors
- EscPosPrinterCommands(DeviceConnection _printerConnection, EscPosCharsetEncoding? charsetEncoding)
-
Create constructor of EscPosPrinterCommands
@param
_printerConnectionan instance of a class which implement DeviceConnection
Properties
- getCharsetEncoding → EscPosCharsetEncoding
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cutPaper(
) → void -
feedPaper(
int dots) → void -
newLine(
) → EscPosPrinterCommands? -
newLineAlign(
List< int> ? align) → EscPosPrinterCommands? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openCashBox(
) → void -
printAllCharsetsEncodingCharacters(
) → void -
printBarcode(
Barcode? barcode) → EscPosPrinterCommands -
printCharsetEncodingCharacters(
int charsetId) → void -
printCharsetsEncodingCharactersWithId(
List< int> charsetsId) → void -
printImage(
Uint8List image) → EscPosPrinterCommands -
printQRCode(
int qrCodeType, String text, int size) → EscPosPrinterCommands -
printText(
String text, List< int> ? textSize, List<int> ? textColor, List<int> ? textReverseColor, List<int> ? textBold, List<int> ? textUnderline, List<int> ? textDoubleStrike) → EscPosPrinterCommands -
reset(
) → void -
setAlign(
Uint8List align) → EscPosPrinterCommands -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertQRCodeToBytes(
String data, int size) → Uint8List -
imageToBytes(
Image imageSrc) → List< int>
Constants
- barcodeTextPositionAbove → const int
- barcodeTextPositionBelow → const int
- barcodeTextPositionNone → const int
- barcodeType128 → const int
- barcodeTypeEAN8 → const int
- barcodeTypeEAN13 → const int
- barcodeTypeUPCA → const int
- barcodeTypeUPCE → const int
- lF → const int
-
lineSpacing16
→ const List<
int> -
lineSpacing24
→ const List<
int> -
lineSpacing30
→ const List<
int> - qrCode1 → const int
- qrCode2 → const int
-
resetLineSpacing
→ const List<
int> -
resetPrinter
→ const List<
int> -
textAlignCenter
→ const List<
int> -
textAlignLeft
→ const List<
int> -
textAlignRight
→ const List<
int> -
textColorBlack
→ const List<
int> -
textColorRed
→ const List<
int> -
textColorReverseOff
→ const List<
int> -
textColorReverseOn
→ const List<
int> -
textDoubleStrikeOff
→ const List<
int> -
textDoubleStrikeOn
→ const List<
int> -
textSizeBig
→ const List<
int> -
textSizeBig2
→ const List<
int> -
textSizeBig3
→ const List<
int> -
textSizeBig4
→ const List<
int> -
textSizeBig5
→ const List<
int> -
textSizeBig6
→ const List<
int> -
textSizeDoubleHeight
→ const List<
int> -
textSizeDoubleWidth
→ const List<
int> -
textSizeNormal
→ const List<
int> -
textUnderLineLarge
→ const List<
int> -
textUnderlineOff
→ const List<
int> -
textUnderLineOn
→ const List<
int> -
textWeightBold
→ const List<
int> -
textWeightNormal
→ const List<
int>